<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
<context>
    <name>notification::BubbleItem</name>
    <message>
        <source>just now</source>
        <translation>juuri nyt</translation>
    </message>
    <message>
        <source>1 new message</source>
        <translation>1 uusi viesti</translation>
    </message>
</context>
<context>
    <name>notification::BubbleModel</name>
    <message>
        <source>%1 minutes ago</source>
        <translation>%1 minuuttia sitten</translation>
    </message>
</context>
</TS>